predicted_corpus = """
<div class="col-md-6">
    <h2>Predicted</h2>
    <p class="text-column">{predicted_html}</p>
</div>
"""
